import { isMongoId } from 'class-validator';
import { Types } from 'mongoose';
import { RESTError } from '../models/dtos/wrappers/rest-wrapper.class';

const toStringArray = (value: string | string[]) => {
    return typeof value === 'string' ? [value] : value;
};

const toMongoId = (value: string) => {
    const check = isMongoId(value);
    if (!check) {
        throw new RESTError('invalid_mongoid', value);
    }
    return Types.ObjectId.createFromHexString(value);
};

const toMongoIdArray = (values: string | string[]) => {
    const result: Types.ObjectId[] = [];
    const items = typeof values === 'string' ? [values] : values;
    for (const value of items) {
        result.push(toMongoId(value));
    }
    return result;
};

const toBoolean = (value: string) => {
    return value === 'true';
};

export { toStringArray, toMongoId, toMongoIdArray, toBoolean };
